@@ -15,6 +15,7 @@ class NWP(DataSourceOutput):
 
     __slots__ = ()
     _expected_dimensions = ("time", "x", "y", "channels")
+    _expected_data_vars = ("data",)
 
     @classmethod
     def model_validation(cls, v):
@@ -22,4 +23,8 @@ class NWP(DataSourceOutput):
 
         v.check_nan_and_inf(data=v.data)
 
+        v.check_data_var_dim(
+            v.data, ("example", "time_index", "x_index", "y_index", "channels_index")
+        )
+
         return v
